@@ -25,6 +25,8 @@ from opentelemetry.exporter.jaeger.proto.grpc import JaegerExporter
 # pylint:disable=import-error
 from opentelemetry.exporter.jaeger.proto.grpc.gen import model_pb2
 from opentelemetry.exporter.jaeger.proto.grpc.translate import (
+    _SCOPE_NAME_KEY,
+    _SCOPE_VERSION_KEY,
     NAME_KEY,
     VERSION_KEY,
     Translate,
@@ -39,7 +41,7 @@ from opentelemetry.sdk.environment_variables import (
 from opentelemetry.sdk.resources import SERVICE_NAME, Resource
 from opentelemetry.sdk.trace import TracerProvider
 from opentelemetry.sdk.trace.export import SpanExportResult
-from opentelemetry.sdk.util.instrumentation import InstrumentationInfo
+from opentelemetry.sdk.util.instrumentation import InstrumentationScope
 from opentelemetry.test.spantestutil import (
     get_span_with_dropped_attributes_events_links,
 )
@@ -188,7 +190,7 @@ class TestJaegerExporter(unittest.TestCase):
                 context=other_context,
                 parent=None,
                 resource=Resource({}),
-                instrumentation_info=InstrumentationInfo(
+                instrumentation_scope=InstrumentationScope(
                     name="name", version="version"
                 ),
             ),
@@ -391,6 +393,16 @@ class TestJaegerExporter(unittest.TestCase):
                         v_type=model_pb2.ValueType.STRING,
                         v_str="version",
                     ),
+                    model_pb2.KeyValue(
+                        key=_SCOPE_NAME_KEY,
+                        v_type=model_pb2.ValueType.STRING,
+                        v_str="name",
+                    ),
+                    model_pb2.KeyValue(
+                        key=_SCOPE_VERSION_KEY,
+                        v_type=model_pb2.ValueType.STRING,
+                        v_str="version",
+                    ),
                 ],
                 process=model_pb2.Process(
                     service_name="svc",
